'use strict';

var index = require('./utils/index.js');
var _const = require('./const.js');
var Graphics = require('./Graphics.js');
var GraphicsGeometry = require('./GraphicsGeometry.js');
require('../core/settings.js');
require('../color.js');
require('../constants.js');
require('../extensions.js');
require('../math/const.js');
require('../math/groupD8.js');
require('../math/Transform.js');
require('../runner.js');
require('../ticker/settings.js');
require('../ticker/const.js');
require('../ticker/Ticker.js');
require('../ticker/TickerPlugin.js');
require('../utils/settings.js');
require('../utils/is_mobile/index.js');
require('../utils/color/premultiply.js');
require('../utils/media/BoundingBox.js');
require('../core/autoDetectRenderer.js');
require('../core/background/BackgroundSystem.js');
require('../core/batch/BatchRenderer.js');
require('../core/shader/Program.js');
require('../core/batch/BatchSystem.js');
require('../core/context/ContextSystem.js');
require('../core/filters/Filter.js');
require('../core/filters/FilterSystem.js');
require('../core/textures/BaseTexture.js');
require('../core/framebuffer/FramebufferSystem.js');
require('../core/framebuffer/MultisampleSystem.js');
require('../core/geometry/BufferSystem.js');
require('../core/geometry/GeometrySystem.js');
require('../core/mask/MaskSystem.js');
require('../core/mask/ScissorSystem.js');
require('../core/mask/StencilSystem.js');
require('../core/plugin/PluginSystem.js');
require('../core/projection/ProjectionSystem.js');
require('../core/render/ObjectRendererSystem.js');
require('../core/Renderer.js');
require('../core/renderTexture/GenerateTextureSystem.js');
require('../core/renderTexture/RenderTexturePool.js');
require('../core/renderTexture/RenderTextureSystem.js');
require('../core/shader/ShaderSystem.js');
require('../core/startup/StartupSystem.js');
require('../core/state/StateSystem.js');
require('../core/textures/TextureGCSystem.js');
require('../core/textures/TextureSystem.js');
require('../core/transformFeedback/TransformFeedbackSystem.js');
require('../core/view/ViewSystem.js');
require('../core/textures/resources/index.js');
var buildCircle = require('./utils/buildCircle.js');
var buildRectangle = require('./utils/buildRectangle.js');
var buildRoundedRectangle = require('./utils/buildRoundedRectangle.js');
var buildPoly = require('./utils/buildPoly.js');
var buildLine = require('./utils/buildLine.js');
var ArcUtils = require('./utils/ArcUtils.js');
var BezierUtils = require('./utils/BezierUtils.js');
var QuadraticUtils = require('./utils/QuadraticUtils.js');
var BatchPart = require('./utils/BatchPart.js');

const graphicsUtils = {
  buildPoly: buildPoly.buildPoly,
  buildCircle: buildCircle.buildCircle,
  buildRectangle: buildRectangle.buildRectangle,
  buildRoundedRectangle: buildRoundedRectangle.buildRoundedRectangle,
  buildLine: buildLine.buildLine,
  ArcUtils: ArcUtils.ArcUtils,
  BezierUtils: BezierUtils.BezierUtils,
  QuadraticUtils: QuadraticUtils.QuadraticUtils,
  BatchPart: BatchPart.BatchPart,
  FILL_COMMANDS: index.FILL_COMMANDS,
  BATCH_POOL: index.BATCH_POOL,
  DRAW_CALL_POOL: index.DRAW_CALL_POOL
};

exports.GRAPHICS_CURVES = _const.GRAPHICS_CURVES;
Object.defineProperty(exports, 'LINE_CAP', {
    enumerable: true,
    get: function () { return _const.LINE_CAP; }
});
Object.defineProperty(exports, 'LINE_JOIN', {
    enumerable: true,
    get: function () { return _const.LINE_JOIN; }
});
exports.curves = _const.curves;
exports.Graphics = Graphics.Graphics;
exports.GraphicsGeometry = GraphicsGeometry.GraphicsGeometry;
exports.graphicsUtils = graphicsUtils;
//# sourceMappingURL=index.js.map
